import cv2
import numpy as np
import sys

facePath = "haarcascade_frontalface_default.xml"
smilePath = "haarcascade_smile.xml"
faceCascade = cv2.CascadeClassifier(facePath)
smileCascade = cv2.CascadeClassifier(smilePath)

cap = cv2.VideoCapture(0)
cap.set(3,640)
cap.set(4,480)

sF = 1.05
print(" Welcome to smile detection project")
while True:
    ret, frame = cap.read() # Capture frame-by-frame
    img = frame
    gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)

    faces = faceCascade.detectMultiScale(
        gray,
        scaleFactor= sF,
        minNeighbors=8,
        minSize=(55, 55),
        flags=cv2.CASCADE_SCALE_IMAGE
    )
    # ---- Draw a rectangle around the faces

    for (x, y, w, h) in faces:
        cv2.rectangle(frame, (x, y), (x+w, y+h), (0, 0, 255), 2)
        roi_gray = gray[y:y+h, x:x+w]
        roi_color = frame[y:y+h, x:x+w]
        smile = smileCascade.detectMultiScale(
            roi_gray,
            scaleFactor= 1.7,
            minNeighbors=22,
            minSize=(25, 25),
            flags=cv2.CASCADE_SCALE_IMAGE
            )

        # Set region of interest for smiles
        for (x, y, w, h) in smile:
            
            # Import GPIO
            import RPi.GPIO as GPIO
            
            # Import sleep
            from time import sleep
            
            # Set the GPIO mode
            GPIO.setmode(GPIO.BCM)
            
            # Define GPIO pins
            Motor1A = 27
            Motor1B = 24
            Motor1Enable = 5
            
            # Set up defined GPIO pins
            GPIO.setup(Motor1A,GPIO.OUT)
            GPIO.setup(Motor1B,GPIO.OUT)
            GPIO.setup(Motor1Enable,GPIO.OUT)
            
            # Turn the motor on
            GPIO.output(Motor1A,GPIO.HIGH) # GPIO high to send power to the + terminal
            GPIO.output(Motor1B,GPIO.LOW) # GPIO low to ground the - terminal
            GPIO.output(Motor1Enable,GPIO.HIGH) # GPIO high to enable this motor
            
            # Leave the motor on for 3 seconds
            sleep(0.5)
            
            # Stop the motor by 'turning off' the enable GPIO pin
            GPIO.output(Motor1Enable,GPIO.LOW)
            
            # Always end this script by cleaning the GPIO
            GPIO.cleanup()

            # print ("Found"), len(smile), ("smile!")
            cv2.rectangle(roi_color, (x, y), (x+w, y+h), (255, 0, 0), 1)
             
        
    cv2.imshow('Smile Detector', frame)
    c = cv2.waitKey(7) % 0x100
    if c == 27:
        break

cap.release()
cv2.destroyAllWindows()
